/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.shotoku.velocity;

import java.io.InputStream;

import org.apache.commons.collections.ExtendedProperties;
import org.apache.velocity.exception.ResourceNotFoundException;
import org.apache.velocity.runtime.resource.Resource;
import org.apache.velocity.runtime.resource.loader.ResourceLoader;
import org.jboss.shotoku.ContentManager;
import org.jboss.shotoku.exceptions.ResourceDoesNotExist;

/**
 * @author Adam Warski (adamw@aster.pl)
 */
public class ShotokuResourceLoader extends ResourceLoader {
	private ContentManager cm;
	
	private boolean isStringEmpty(String s) {
		return (s == null) || ("".equals(s));
	}
	
	@Override
	public void init(ExtendedProperties properties) {
		String prefix = properties.getString("prefix");
		String id = properties.getString("id");
		
		if ((isStringEmpty(prefix)) && (isStringEmpty(id))) {
			cm = ContentManager.getContentManager();
		} else if (isStringEmpty(id)) {
			cm = ContentManager.getContentManager(prefix);
		} else {
			cm = ContentManager.getContentManager(id, prefix);
		}
	}

	@Override
	public InputStream getResourceStream(String resource) throws ResourceNotFoundException {
		try {
			return cm.getNode(resource).getContentInputStream();
		} catch (ResourceDoesNotExist e) {
			throw new ResourceNotFoundException(e.getMessage());
		}
	}

	@Override
	public boolean isSourceModified(Resource resource) {
		try {
			return resource.getLastModified() != cm.getNode(resource.getName()).getLastModification();
		} catch (ResourceDoesNotExist e) {
			return false;
		}
	}

	@Override
	public long getLastModified(Resource resource) {
		try {
			return cm.getNode(resource.getName()).getLastModification();
		} catch (ResourceDoesNotExist e) {
			return 0;
		}
	}

}

